==> parcel-bundler-vue-1.6.3.tgz: package/lib/HMRServer.js <==
'use strict';

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var http = require('http');
var https = require('https');
var WebSocket = require('ws');
var prettyError = require('./utils/prettyError');
var generateCertificate = require('./utils/generateCertificate');
var logger = require('./Logger');

var HMRServer = function () {
  function HMRServer() {
    (0, _classCallCheck3.default)(this, HMRServer);
  }

  (0, _createClass3.default)(HMRServer, [{
    key: 'start',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
        var _this = this;

        var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.next = 2;
                return new _promise2.default(function (resolve) {
                  var server = options.https ? https.createServer(generateCertificate(options)) : http.createServer();

                  _this.wss = new WebSocket.Server({ server: server });
                  server.listen(options.hmrPort, resolve);
                });

              case 2:

                this.wss.on('connection', function (ws) {
                  ws.onerror = _this.handleSocketError;
                  if (_this.unresolvedError) {
                    ws.send((0, _stringify2.default)(_this.unresolvedError));
                  }
                });

                this.wss.on('error', this.handleSocketError);

                return _context.abrupt('return', this.wss._server.address().port);

              case 5:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function start() {
        return _ref.apply(this, arguments);
      }

      return start;
    }()
  }, {
    key: 'stop',
    value: function stop() {
      this.wss.close();
    }
  }, {
    key: 'emitError',
    value: function emitError(err) {
      var _prettyError = prettyError(err),
          message = _prettyError.message,
          stack = _prettyError.stack;

      // store the most recent error so we can notify new connections
      // and so we can broadcast when the error is resolved


      this.unresolvedError = {
        type: 'error',
        error: {
          message: message,
          stack: stack
        }
      };

      this.broadcast(this.unresolvedError);
    }
  }, {
    key: 'emitUpdate',
    value: function emitUpdate(assets) {
      if (this.unresolvedError) {
        this.unresolvedError = null;
        this.broadcast({
          type: 'error-resolved'
        });
      }

      var containsHtmlAsset = assets.some(function (asset) {
        return asset.type === 'html';
      });
      if (containsHtmlAsset) {
        this.broadcast({
          type: 'reload'
        });
      } else {
        this.broadcast({
          type: 'update',
          assets: assets.map(function (asset) {
            var deps = {};
            var _iteratorNormalCompletion = true;
            var _didIteratorError = false;
            var _iteratorError = undefined;

            try {
              for (var _iterator = (0, _getIterator3.default)(asset.depAssets), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
                var _ref2 = _step.value;

                var _ref3 = (0, _slicedToArray3.default)(_ref2, 2);

                var dep = _ref3[0];
                var depAsset = _ref3[1];

                deps[dep.name] = depAsset.id;
              }
            } catch (err) {
              _didIteratorError = true;
              _iteratorError = err;
            } finally {
              try {
                if (!_iteratorNormalCompletion && _iterator.return) {
                  _iterator.return();
                }
              } finally {
                if (_didIteratorError) {
                  throw _iteratorError;
                }
              }
            }

            return {
              id: asset.id,
              generated: asset.generated,
              deps: deps
            };
          })
        });
      }
    }
  }, {
    key: 'handleSocketError',
    value: function handleSocketError(err) {
      if (err.error.code === 'ECONNRESET') {
        // This gets triggered on page refresh, ignore this
        return;
      }
      logger.warn(err);
    }
  }, {
    key: 'broadcast',
    value: function broadcast(msg) {
      var json = (0, _stringify2.default)(msg);
      var _iteratorNormalCompletion2 = true;
      var _didIteratorError2 = false;
      var _iteratorError2 = undefined;

      try {
        for (var _iterator2 = (0, _getIterator3.default)(this.wss.clients), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
          var ws = _step2.value;

          ws.send(json);
        }
      } catch (err) {
        _didIteratorError2 = true;
        _iteratorError2 = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion2 && _iterator2.return) {
            _iterator2.return();
          }
        } finally {
          if (_didIteratorError2) {
            throw _iteratorError2;
          }
        }
      }
    }
  }]);
  return HMRServer;
}();

module.exports = HMRServer;

==> parcel-bundler-vue-2.0.0.tgz: package/lib/HMRServer.js <==
'use strict';

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var WebSocket = require('ws');
var prettyError = require('./utils/prettyError');

var HMRServer = function () {
  function HMRServer() {
    (0, _classCallCheck3.default)(this, HMRServer);
  }

  (0, _createClass3.default)(HMRServer, [{
    key: 'start',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(port) {
        var _this = this;

        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.next = 2;
                return new _promise2.default(function (resolve) {
                  _this.wss = new WebSocket.Server({ port: port }, resolve);
                });

              case 2:

                this.wss.on('connection', function (ws) {
                  ws.onerror = _this.handleSocketError;
                  if (_this.unresolvedError) {
                    ws.send((0, _stringify2.default)(_this.unresolvedError));
                  }
                });

                this.wss.on('error', this.handleSocketError);

                return _context.abrupt('return', this.wss._server.address().port);

              case 5:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function start(_x) {
        return _ref.apply(this, arguments);
      }

      return start;
    }()
  }, {
    key: 'stop',
    value: function stop() {
      this.wss.close();
    }
  }, {
    key: 'emitError',
    value: function emitError(err) {
      var _prettyError = prettyError(err),
          message = _prettyError.message,
          stack = _prettyError.stack;

      // store the most recent error so we can notify new connections
      // and so we can broadcast when the error is resolved


      this.unresolvedError = {
        type: 'error',
        error: {
          message: message,
          stack: stack
        }
      };

      this.broadcast(this.unresolvedError);
    }
  }, {
    key: 'emitUpdate',
    value: function emitUpdate(assets) {
      if (this.unresolvedError) {
        this.unresolvedError = null;
        this.broadcast({
          type: 'error-resolved'
        });
      }

      var containsHtmlAsset = assets.some(function (asset) {
        return asset.type === 'html';
      });
      if (containsHtmlAsset) {
        this.broadcast({
          type: 'reload'
        });
      } else {
        this.broadcast({
          type: 'update',
          assets: assets.map(function (asset) {
            var deps = {};
            var _iteratorNormalCompletion = true;
            var _didIteratorError = false;
            var _iteratorError = undefined;

            try {
              for (var _iterator = (0, _getIterator3.default)(asset.depAssets), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
                var _ref2 = _step.value;

                var _ref3 = (0, _slicedToArray3.default)(_ref2, 2);

                var dep = _ref3[0];
                var depAsset = _ref3[1];

                deps[dep.name] = depAsset.id;
              }
            } catch (err) {
              _didIteratorError = true;
              _iteratorError = err;
            } finally {
              try {
                if (!_iteratorNormalCompletion && _iterator.return) {
                  _iterator.return();
                }
              } finally {
                if (_didIteratorError) {
                  throw _iteratorError;
                }
              }
            }

            return {
              id: asset.id,
              generated: asset.generated,
              deps: deps
            };
          })
        });
      }
    }
  }, {
    key: 'handleSocketError',
    value: function handleSocketError(err) {
      if (err.code === 'ECONNRESET') {
        // This gets triggered on page refresh, ignore this
        return;
      }
      // TODO: Use logger to print errors
      console.log(prettyError(err));
    }
  }, {
    key: 'broadcast',
    value: function broadcast(msg) {
      var json = (0, _stringify2.default)(msg);
      var _iteratorNormalCompletion2 = true;
      var _didIteratorError2 = false;
      var _iteratorError2 = undefined;

      try {
        for (var _iterator2 = (0, _getIterator3.default)(this.wss.clients), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
          var ws = _step2.value;

          ws.send(json);
        }
      } catch (err) {
        _didIteratorError2 = true;
        _iteratorError2 = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion2 && _iterator2.return) {
            _iterator2.return();
          }
        } finally {
          if (_didIteratorError2) {
            throw _iteratorError2;
          }
        }
      }
    }
  }]);
  return HMRServer;
}();

module.exports = HMRServer;
